{% extends base.html %}
{% block title %}
Home
{% end block %}

{% block body %}
<center>
  <div class=jumbotron>
    <H1>Welcome to Magpie!</H1>
    <img src="{{ static_url('magpie.jpg') }}"><br><br>
    <p class=lead>
    I <b><i>love</i></b> <a target=_blank href=https://evernote.com>Evernote</a>,
     but I just don't trust anybody with data I care about anymore, so I
    decided to try to build a replacement I could host myself.  Magpie is an
    Evernote replacement which renders Markdown, is backed by git, and is built
    on Python.
    </p>
    {% if config_problem is not None %}
      <p class=bg-{{ config_problem['type'] }}>
      {{ config_problem['message'] }}
      <br>
      <a href=/config>Click here to change your settings.</a>
      </p>
    {% end if %}
  </div>
  <p class=small>
  <a href="http://www.kpword.net/" target="_blank" rel="nofollow">Image
  courtesy of Kieran Palmer, as licensed under CC BY-SA 2.0 Generic.</a>
  </p>
</center>
{% end block %}
