{% extends base.html %}
{% block title %}login{% end block %}

{% block body %}
<center>
{% if error is not None %}
  <p class=bg-danger>
    {{ error }}
  </p>
{% end if %}
<H1>Login</H1>
<form method=POST>
<input type=text name=username placeholder=" username" tabindex="1">
<br>
<br>
<input type=password name=password placeholder=" password" tabindex="2">
<br>
<br>
<input type=submit class='btn btn-primary' value=Login>
</form>
</center>
{% end block %}
